#ifndef ROBODOC_CONFIG_H
#define ROBODOC_CONFIG_H

typedef enum
{
    CFL_REMARK = 0,
    CFL_PARAMETER,
    CFL_SECTION,
    CFL_EMPTYLINE,
    CFL_UNKNOWN
}
T_Line_Kind;

typedef enum
{
    SK_ITEMS = 0,
    SK_IGNOREITEMS,
    SK_OPTIONS,
    SK_EXTENSIONS,
    SK_HEADERTYPES,
    SK_UNKNOWN
}
T_Section_Kind;


struct Parameters {
    unsigned int        number;
    unsigned int        size;
    char              **names;  
};

/****s* Configuration/RB_Configuration
 * FUNCTION
 *   All the data from the robodoc.rc file is stored in this
 *   structure.
 * ATTRIBUTES
 *   itemnames       -- an array with names that robodoc recognizes as
 *                      items.  Alsways includes the name "SOURCE" as
 *                      the first element.
 *   no_items        -- the total number of names.
 *   ignore_items    -- an array with the names of items that ROBODoc
 *                      should ignore.
 *   no_ignore_items -- the total number of these names.
 *   options         -- Array with all options specified both on the
 *                      commandline as well as in the robodoc.rc file.
 *   no_options      -- the total number of options.
 *   extensions      -- Array with all file name extensions that
 *                      should be ignored during a directory scan.
 *   no_extensions   -- the total number of extensions.
 * SOURCE
 */

struct RB_Configuration
{
    /* Itemnames  */
    unsigned int        no_items;
    char              **item_names;     /* Array with itemnames. */
    /* IgnoreItems */
    unsigned int        no_ignore_items;
    char              **ignore_items;
    /* Commandline options. */
    int                 argc;   /* Number of options specified on the command line.  */
    unsigned int        no_options;
    char              **options;        /* Array with all options. */
    /* filename extensions will be excluded */
    unsigned int        no_extensions;
    char              **extensions;
    /* headertypes */
    /* TODO, the following mechanism should also be used
     * for the above arrays.
     */
    struct Parameters   custom_headertypes;
};

/*******/

char               *RB_GetParameter( char *line );
void                RB_ReadConfiguration( int argc, char **argv, char* filename );
void                RB_StripCR( char *line );
void                RB_Free_Configuration(  );

extern struct RB_Configuration configuration;

#endif
